# yum-newrelic Cookbook
[![Build Status](https://travis-ci.org/chasebolt/chef-yum-newrelic.svg?branch=master)](http://travis-ci.org/chasebolt/chef-yum-newrelic) [![Cookbook Version](https://img.shields.io/cookbook/v/yum-newrelic.svg)](https://supermarket.chef.io/cookbooks/yum-newrelic)

The yum-newrelic cookbook takes over management of the default repositoryids used with the official newrelic repositories. It allows attribute manipulation of the `newrelic` yum channel.

## Requirements
- Chef 11+
- yum version 3.2.0 or higher

### Platforms
- Fedora and RHEL based distributions (RHEL, CentOS, and Scientific Linux) are supported

## Attributes
The following attributes are set by default

```ruby
default['yum']['newrelic']['description'] = 'New Relic packages for Enterprise Linux 5 - $basearch'
default['yum']['newrelic']['baseurl'] = 'http://yum.newrelic.com/pub/newrelic/el5/$basearch'
default['yum']['newrelic']['gpgkey'] = 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-NewRelic'
default['yum']['newrelic']['gpgcheck'] = true
default['yum']['newrelic']['enabled'] = true
default['yum']['newrelic']['managed'] = true

```

## Recipes
- default - Walks through node attributes and feeds a yum_resource
- parameters. The following is an example a resource generated by the
- recipe during compilation.

```ruby
  yum_repository 'newrelic' do
    baseurl 'http://yum.newrelic.com/pub/newrelic/el5/$basearch'
    description 'New Relic Repository'
    enabled true
    gpgcheck true
    gpgkey 'http://www.newrelic.com/downloads/RPM-GPG-KEY-newrelic'
  end
```

## Usage Example
To disable the newrelic repository through a Role or Environment definition

```ruby
default_attributes(
  :yum => {
    :newrelic => {
      :enabled => {
        false
       }
     }
   }
 )
```

To enable the newrelic repository with a wrapper cookbook, place the following in a recipe:

```ruby
node.default['yum']['newrelic']['enabled'] = true
include_recipe 'yum-newrelic'
```

## More Examples
Point the base and updates repositories at an internally hosted server.

```ruby
node.default['yum']['newrelic']['enabled'] = true
node.default['yum']['newrelic']['mirrorlist'] = nil
node.default['yum']['newrelic']['baseurl'] = 'https://internal.example.com/newrelic/6/os/x86_64'
node.default['yum']['newrelic']['sslverify'] = false

include_recipe 'yum-newrelic'
```

## Maintainers

* Chase Bolt (<chase.bolt@gmail.com>)

## License
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
